UiPath Documentation
automation-suite
2023.4
false
Linux の Automation Suite のインストール ガイド
重要 :
このコンテンツの一部は機械翻訳によって処理されており、完全な翻訳を保証するものではありません。 新しいコンテンツの翻訳は、およそ 1 ~ 2 週間で公開されます。

install-uipath.sh パラメーター

install-uipath.sh 手動インストーラーを使用すると、対話型インストーラー (installUiPathAS.sh) を実行することなくインストール エクスペリエンスをカスタマイズできます。

手動インストーラーは高度なシナリオに適していますが、デプロイ テンプレートと対話型インストーラーが引き続き推奨オプションです。

The install-uipath.sh installer is available in as-installer.zip. For download instructions, see Downloading installation packages.

必須パラメーター​

--input -i <string>​

入力 .json ファイルを指定します。

input.json refers to the cluster_config.json that defines the parameters, settings, and preferences applied to the UiPath® services deployed via Automation Suite. You need to update this file to change the defaults and use any advanced configuration for your cluster. For details, refer to Manual: Advanced installation experience.

--output -o <string>​

出力 .json ファイルを指定します。

output.json は、手動インストーラーの出力ファイルを参照します。

任意パラメーター​

--install-kubernetes -k​

Kubernetes クラスターをインストールします。

--join-node -j <server|agent>​

-k を指定する場合にのみ使用します。既存のクラスターに参加させるノードの種類を決定します。許容値: <server|agent>

--install-fabric -f​

ファブリック コンポーネントをインストールします。

--install-services -s​

UiPath サービスをインストールします。

--install-all -a​

すべてのインストーラーを順番に実行します。インストールを明示的に選択しない場合、暗黙的に –install-all が選択されます。

--install-type <online|offline>​

インストールの種類を指定します。既定値は online です。online と –offline-bundle を同時に設定することはできません。

--offline-bundle <string>​

オフライン バンドルへのパスを指定します。インストール方法が tarball であることを示します。

--offline-tmp-folder <string>​

--offline-bundle または --optional-offline-bundle とともに使用できる任意のフラグです。オフライン インストールの一時フォルダーの親ディレクトリを指定します。既定は /tmp になります。

--optional-offline-bundle <string>​

オプションのオフライン バンドルへのパスを指定します。

--pre-reqs -p​

前提条件を確認します。このフラグを使用する場合、他のフラグを渡すことはできません。

--install-offline-prereqs​

tarball のインストール方法と組み合わせて使用します。すべての前提条件のインストールを実行します。

--skip-packages-install​

オンラインのインストール方法において前提条件のインストールを省略します。既定では、前提条件がインストールされます。

--upgrade -u​

既存の Automation Suite クラスターをアップグレードします。

--kubeconfig <string>​

kubeconfig ファイルへのパスを指定します。このフラグを指定しないと、既定の /etc/rancher/rke2/rke2.yaml が指定されます。

--backup -b​

クラスターをバックアップします。

--restore -r​

クラスターを復元します。

--restore-volume​

ボリュームを復元します。

--disable-backup​

バックアップを無効化します。

デバッグ モードで実行します。

ヘルプを表示します。

--accept-license-agreement​

ライセンス契約に同意する必須のフラグです。

Cilium CNI (コンテナー ネットワーク インターフェイス) をインストールして既定の Canal を置き換えます。アップグレード時にのみ使用します。インストール フラグと一緒には使用できません。

--skip-pre-reqs​

インストール時の前提条件の確認をスキップします。RPM パッケージの検証はスキップできないことに注意してください。

--one-time-manual-backup​

手動バックアップをトリガーし、完了後に無効化します。

-m|--machines <comma separated machine's IP>​

インストール先マシンを指定します。すべてのマシンの IP アドレスまたはホスト名をコンマで区切って指定します。

--compare-config​

現在の構成ファイルをクラスター ステートと比較します。input.json ファイルを現在のクラスター構成と比較します。

--skip-compare-config​

現在の構成とクラスター ステートとの比較をスキップします。

  • Kubernetes クラスターのコンポーネントを、その実行場所となる仮想マシンにオンラインによる方法でインストールします。

    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement
    
  • Kubernetes コンポーネントを、その実行場所となる仮想マシンにオンラインによる方法でインストールし、既存のクラスターにサーバーとして参加させます。

    install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement
    
  • 現在の仮想マシンにオンラインによる方法で完全なインストールを実行します。これには、Kubernetes クラスターのコンポーネント、ファブリック、および UiPath のサービスが含まれます。

    install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement
    
  • 現在の仮想マシンにオンラインによる方法で完全なインストールを実行します。この場合は、前提条件のインストールをスキップします。

    install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement
    
  • tarball による方法で Kubernetes クラスターのインストールを実行します。さらに、既存のクラスターにノードを参加させ、すべてのオフライン前提条件をインストールします。

    install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement --install-offline-prereqs
    install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement --install-offline-prereqs
    
  • オフラインによる方法で、一時フォルダーを指定せずに、ファブリックおよびサービスのコンポーネントをインストールします。

    install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/as-infra.tar.gz" --accept-license-agreement
    
  • オフライン インストールでインストーラーを実行しますが、成果物は読み込みません。

    install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement
    install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement
    
  • 前提条件の確認をスキップしてインストーラーを実行します。

    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
    install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
    

このページは役に立ちましたか?

接続

ヘルプ リソース サポート

学習する UiPath アカデミー

質問する UiPath フォーラム

最新情報を取得